#
# spec file for package ghc-safe
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name safe
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.3.19
Release:        150500.1.1
Summary:        Library of safe (exception free) functions
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-deepseq-devel
%endif

%description
A library wrapping 'Prelude'/'Data.List' functions that can throw exceptions,
such as 'head' and '!!'. Each unsafe function has up to four variants, e.g.
with 'tail':

* 'tail :: [a] -> [a]', raises an error on 'tail []'.

* 'tailMay :: [a] -> /Maybe/ [a]', turns errors into 'Nothing'.

* 'tailDef :: /[a]/ -> [a] -> [a]', takes a default to return on errors.

* 'tailNote :: /String/ -> [a] -> [a]', takes an extra argument which
supplements the error message.

* 'tailSafe :: [a] -> [a]', returns some sensible default if possible, '[]' in
the case of 'tail'.

This package is divided into three modules:

* "Safe" contains safe variants of 'Prelude' and 'Data.List' functions.

* "Safe.Foldable" contains safe variants of 'Foldable' functions.

* "Safe.Exact" creates crashing versions of functions like 'zip' (errors if the
lists are not equal) and 'take' (errors if there are not enough elements), then
wraps them to provide safe variants.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGES.txt README.md

%changelog
* Thu Dec 17 2020 mimi.vx@gmail.com
- disable %%{ix86} build
* Tue Aug 18 2020 psimons@suse.com
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Update safe to version 0.3.19.
  0.3.19, released 2020-05-24
    [#30], undeprecate maximumDef and friends, fold*1Def
* Thu Dec  5 2019 psimons@suse.com
- Update safe to version 0.3.18.
  0.3.18, released 2019-12-04
    [#27], deprecate maximumDef and friends, fold*1Def
    [#27], add maximumBounded and friends
    Stop supporting GHC 7.4 to 7.8
* Fri Nov  8 2019 psimons@suse.com
- Drop obsolete group attributes.
* Sat Oct 20 2018 psimons@suse.com
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update safe to version 0.3.17.
  * Improve the display of errors, less internal callstack
  * Add a few missing Partial constraints
  * #22, add Safe index
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Jun 25 2017 psimons@suse.com
- Update to version 0.3.15.
* Mon Feb 20 2017 psimons@suse.com
- Update to version 0.3.14 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 0.3.13 with cabal2obs.
* Thu Jan 26 2017 psimons@suse.com
- Update to version 0.3.11 with cabal2obs.
* Mon Nov 14 2016 psimons@suse.com
- Update to version 0.3.10 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.3.9 revision 0 with cabal2obs.
* Fri Oct 23 2015 mimi.vx@gmail.com
- initial commit
